==> 0.0.8.tar.gz: ios/Classes/SwiftAirexSwiftPlugin.swift <==
import Flutter
import UIKit
import Appier

public class SwiftAirexSwiftPlugin: NSObject, FlutterPlugin {
  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "airex_swift_plugin", binaryMessenger: registrar.messenger())
    let instance = SwiftAirexSwiftPlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)
  }

public func handle(_ call: FlutterMethodCall, result: FlutterResult) {

    let arguments:[String : Any] = call.arguments as! [String : Any]
    print(arguments)
    if "configure" == call.method {

        let appId:String? = arguments["appId"] as? String
        let appGroup:String? = arguments["appGroup"] as? String
        let isDev:Bool? = arguments["isDev"] as? String
        print("appId:\(appId)")
        print("appGroup:\(appGroup")")
        print("isDev:\(isDev) (isDev!)")
        QGSdk.getSharedInstance().onStart(appId, withAppGroup: appGroup, setDevProfile: isDev)
        result(nil)
        return
    } else if "logEvent" == call.method {

        var parameters: [String : Any]? = nil
        if call.arguments["parameters"]: [String : Any]? != nil {
            if let object = call.arguments["parameters"] {
                print("parameters: \(object)")
            }
            parameters = call.arguments["parameters"] as? [AnyHashable : Any]
        }

        let vts = call.arguments["vts"] as? NSNumber
        print("vtc class Name \(NSStringFromClass(type(of: vts).self))")

        let vtsCurr = call.arguments["vtsCurr"] as? NSNumber
        print("vtsCurr class Name \(NSStringFromClass(type(of: vtsCurr).self))")

        if call.arguments["eventName"] != nil {
            QGSdk.getSharedInstance().logEvent(call.arguments["eventName"], withParameters: parameters, withValueToSum: vts, withValueToSumCurrency: vtsCurr)
        }

        result(nil)
    } else {
        result(FlutterMethodNotImplemented)
    }
    */
  }
}

==> 0.0.9.tar.gz: ios/Classes/SwiftAirexSwiftPlugin.swift <==
import Flutter
import UIKit
import Appier

public class SwiftAirexSwiftPlugin: NSObject, FlutterPlugin {
  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "airex_swift_plugin", binaryMessenger: registrar.messenger())
    let instance = SwiftAirexSwiftPlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)
  }

public func handle(_ call: FlutterMethodCall, result: FlutterResult) {

    let arguments:[String : Any] = call.arguments as! [String : Any]
    print(arguments)
    if "configure" == call.method {

        let appId:String? = arguments["appId"] as? String
        let appGroup:String? = arguments["appGroup"] as? String
        let isDev:Bool? = arguments["isDev"] as? String
        print("appId:\(appId)")
        print("appGroup:\(appGroup)")
        print("isDev:\(isDev) (isDev!)")
        QGSdk.getSharedInstance().onStart(appId, withAppGroup: appGroup, setDevProfile: isDev)
        result(nil)
        return
    } else if "logEvent" == call.method {

        var parameters: [String : Any]? = nil
        if call.arguments["parameters"]: [String : Any]? != nil {
            if let object = call.arguments["parameters"] {
                print("parameters: \(object)")
            }
            parameters = call.arguments["parameters"] as? [AnyHashable : Any]
        }

        let vts = call.arguments["vts"] as? NSNumber
        print("vtc class Name \(NSStringFromClass(type(of: vts).self))")

        let vtsCurr = call.arguments["vtsCurr"] as? NSNumber
        print("vtsCurr class Name \(NSStringFromClass(type(of: vtsCurr).self))")

        if call.arguments["eventName"] != nil {
            QGSdk.getSharedInstance().logEvent(call.arguments["eventName"], withParameters: parameters, withValueToSum: vts, withValueToSumCurrency: vtsCurr)
        }

        result(nil)
    } else {
        result(FlutterMethodNotImplemented)
    }
    */
  }
}
